#! /usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Replacement (unofficial) `setup.py` for the `note` module.
Automatically generated by `openerpdist`. See http://noteed.com/openerpdist/.
"""

import setuptools

setuptools.setup(
    name = "openerp-note",
    version = "7.0.406",
    description = "Notes",
    long_description = 
"""

This module allows users to create their own notes inside OpenERP
=================================================================

Use notes to write meeting minutes, organize ideas, organize personnal todo
lists, etc. Each user manages his own personnal Notes. Notes are available to
their authors only, but they can share notes to others users so that several
people can work on the same note in real time. It's very efficient to share
meeting minutes.

Notes can be found in the 'Home' menu.
""",
    url = "http://openerp.com",
    author = "OpenERP SA",
    author_email = "TODO",
    classifiers = [
        "Development Status :: 5 - Production/Stable",
        "Environment :: Plugins",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU Affero General Public License v3",
        "Natural Language :: English",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: Implementation :: CPython",
    ],
    license = "AGPL-3",
    package_dir = {
        'openerp.addons.note': ".",
    },
    packages = ["openerp.addons.note","openerp.addons.note.tests"],
    package_data = {
        'openerp.addons.note': ["i18n/*.po*","note_demo.xml","note_view.xml","note_data.xml","images/note_kanban.jpeg","images/note.jpeg","images/categories_tree.jpeg","static/src/img/icon.png","i18n/id.po","i18n/hr.po","i18n/sl.po","i18n/ru.po","i18n/cs.po","i18n/pt_BR.po","i18n/ro.po","i18n/es.po","i18n/mn.po","i18n/it.po","i18n/nl.po","i18n/sv.po","i18n/bs.po","i18n/tr.po","i18n/de.po","i18n/lt.po","i18n/hu.po","i18n/mk.po","i18n/fr.po","i18n/zh_CN.po","i18n/pl.po","i18n/pt.po","security/ir.model.access.csv","security/note_security.xml","security/ir.rule.xml","security/note_security.xml","security/ir.rule.xml","security/ir.model.access.csv","note_data.xml","note_view.xml","note_demo.xml","static/src/css/note.css"],
    },
    install_requires = ["openerp-mail"],
    tests_require = ["unittest2"],
)
